SystemOrganization addCategory: #ConfigurationOfSourceCity!

Object subclass: #ConfigurationOfSourceCity
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSourceCity'!

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:37'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed a bug'
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '- fixed a bug'
	- save configuration
		self saveConfiguration: '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: '- release'
"
	<apiDocumentation>! !

!ConfigurationOfSourceCity class methodsFor: 'private' stamp: 'ErwanDouaille 7/4/2013 13:38'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSourceCity class methodsFor: 'operations' stamp: 'ErwanDouaille 7/4/2013 13:38'!
commit: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	<apiDocumentation>
	self ensureMetacello.
	self updateConfiguration.
	self createNewDevelopmentVersion.
	self updateToLatestPackageVersions: commitMessage.
	self saveModifiedPackagesAndConfiguration: commitMessage.
	self loadDevelopment.
	self saveConfiguration: commitMessage.! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:38'!
compareVersions
	"Compare the #stable version to #development version"

	"self compareVersions"

	<apiDocumentation>
	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:38'!
createNewBaselineVersion
	"Create a new baseline version based upon the #stable version's baseline.
	 A new baseline should be created if new packages have been added or package dependencies have changed."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewBaselineVersionIn: self description: ''
! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:38'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfSourceCity class methodsFor: 'private' stamp: 'ErwanDouaille 7/4/2013 13:38'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfSourceCity class methodsFor: 'testing' stamp: 'ErwanDouaille 7/4/2013 13:38'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSourceCity class methodsFor: 'actions' stamp: 'DiegoLont 1/27/2014 14:14'!
load
	"Load the #development version defined for this platform. The #development version is the version that is recommended to be used on this platform, as there is no stable version at the mmoment."

	"self load"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSourceCity class methodsFor: 'loading' stamp: 'ErwanDouaille 7/4/2013 13:38'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSourceCity class methodsFor: 'loading' stamp: 'ErwanDouaille 7/4/2013 13:38'!
loadDefault
	self load! !

!ConfigurationOfSourceCity class methodsFor: 'loading' stamp: 'ErwanDouaille 7/4/2013 13:38'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSourceCity class methodsFor: 'accessing' stamp: 'ErwanDouaille 7/4/2013 13:38'!
project

	^self new project! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:38'!
releaseDevelopmentVersion: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	<apiDocumentation>
	self ensureMetacello.
	self updateConfiguration.
	self loadDevelopment.
	self createNewDevelopmentVersion.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:39'!
saveConfiguration: commitMessage
	"Save mcz file that contains the configuration to it's repository."

	"self saveConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:39'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update the #development version and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	self updateConfiguration.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:39'!
updateConfiguration
	[[[ 
		(Smalltalk at: #Gofer) new
			package: self name;
			merge ] 	
			on: (Smalltalk at: #MCMergeOrLoadWarning ifAbsent: [ nil ]) 		do: [ :e| e resume: false ]] 		
			on: (Smalltalk at: #MCNoChangesException ifAbsent: [ nil ]) 		do: [ :e| e resume]] 
			on: (Smalltalk at: #MCMergeResolutionRequest ifAbsent: [ nil ]) 	do: [ :request |
																						request merger conflicts isEmpty
																							ifTrue: [ request resume: true ]
																							ifFalse: [ request pass ]].! !

!ConfigurationOfSourceCity class methodsFor: 'development support' stamp: 'ErwanDouaille 7/4/2013 13:39'!
updateToLatestPackageVersions: descriptionString
	"Update the #development version to match currently loaded mcz files."

	"self updateToLatestPackageVersions: '- fixed a bug'"

	<apiDocumentation>
	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSourceCity class methodsFor: 'validation' stamp: 'ErwanDouaille 7/4/2013 13:39'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSourceCity methodsFor: 'baselines' stamp: 'ErwanDouaille 7/4/2013 13:34'!
baseline01: spec
	<version: '0.1-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/ErwanDouaille/SourceCity/main'.
			
			self 
				nbOpenGL: spec.
		
         	spec 
				package: 'SourceCity-Core' with: [ spec requires: 'NBOpenGL' ];
				package: 'SourceCity-Importer' with: [ spec requires: 'NBOpenGL' ];
				package: 'SourceCity-Layout' with: [ spec requires: 'SourceCity-Importer' ];
				package: 'SourceCity-OpenGL' with: [ spec requires: 'NBOpenGL' ];
				package: 'SourceCity-Tools' with: [ spec requires: 'NBOpenGL' ].	
			
			spec 
				group: 'default' with: #(
					'SourceCity-Core' 
					'SourceCity-Importer' 
					'SourceCity-Layout' 
					'SourceCity-OpenGL' 
					'SourceCity-Tools' );
					
				group: 'full' with: #(
					'SourceCity-Core' 
					'SourceCity-Importer' 
					'SourceCity-Layout' 
					'SourceCity-OpenGL' 
					'SourceCity-Tools' ).]! !

!ConfigurationOfSourceCity methodsFor: 'baselines' stamp: 'ErwanDouaille 7/4/2013 13:35'!
baselineDev: spec
	<version: 'dev-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/ErwanDouaille/SourceCity/main'.
			
			self 
				nbOpenGL: spec.
		
         	spec 
				package: 'SourceCity-Core' with: [ spec requires: 'NBOpenGL' ];
				package: 'SourceCity-Importer' with: [ spec requires: 'NBOpenGL' ];
				package: 'SourceCity-Layout' with: [ spec requires: 'SourceCity-Importer' ];
				package: 'SourceCity-OpenGL' with: [ spec requires: 'NBOpenGL' ];
				package: 'SourceCity-Tools' with: [ spec requires: 'NBOpenGL' ].	
			
			spec 
				group: 'default' with: #(
					'SourceCity-Core' 
					'SourceCity-Importer' 
					'SourceCity-Layout' 
					'SourceCity-OpenGL' 
					'SourceCity-Tools' );
					
				group: 'full' with: #(
					'SourceCity-Core' 
					'SourceCity-Importer' 
					'SourceCity-Layout' 
					'SourceCity-OpenGL' 
					'SourceCity-Tools' ).]! !

!ConfigurationOfSourceCity methodsFor: 'versions' stamp: 'ErwanDouaille 7/4/2013 13:35'!
bleedingEdge: spec  
	<symbolicVersion: #bleedingEdge >
	
	spec for: #common version: 'devBleedingEdge'.! !

!ConfigurationOfSourceCity methodsFor: 'versions' stamp: 'ErwanDouaille 7/4/2013 13:36'!
development: spec
	<symbolicVersion: #development >
	
	spec for: #'common' version: 'dev'.
! !

!ConfigurationOfSourceCity methodsFor: 'accessing' stamp: 'a 8/29/2013 16:20'!
nbOpenGL: spec

	"Dependencies"
	spec project: 'NBOpenGL' with: [
		spec 
			repository: 'http://smalltalkhub.com/mc/PharoExtras/NBOpenGL/main';
			className: 'ConfigurationOfNBOpenGL'].! !

!ConfigurationOfSourceCity methodsFor: 'accessing' stamp: 'ErwanDouaille 7/4/2013 13:49'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSourceCity methodsFor: 'versions' stamp: 'DiegoLont 1/27/2014 14:14'!
stable: spec
	<symbolicVersion: #stable >
	
	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfSourceCity methodsFor: 'versions' stamp: 'ErwanDouaille 7/4/2013 13:40'!
versionDevelopmentBleedingEdge: spec
	<version: 'devBleedingEdge' imports: #('dev-baseline')>

	spec for: #'common' do: [
		self versionDevelopmentExternal: spec.  ].
! !

!ConfigurationOfSourceCity methodsFor: 'versions' stamp: 'DiegoLont 1/27/2014 14:15'!
versionDevelopmentExternal: spec
	spec 
		project: 'NBOpenGL'	with: '3.0'.
	! !
